// ----------------------------------------------------------------------------
// FormulaSymbol.java
// Entries in FormulaTable.
// $Id: FormulaSymbol.java,v 1.2 2006/01/15 15:30:40 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.Semantics;

import fmrisc.Proving.*;
import fmrisc.Syntax.*;

/**
 * 
 * Entries in FormulaTable.
 *
 */
public final class FormulaSymbol extends SymbolBase
{
  private Expression formula;    // the formula
  private Environment env;       // the environment in which it was declared
  private Proof proof;           // a proof of the formula
  private boolean axiom = false; // true iff formula is axiom
  
  /****************************************************************************
   * Construct formula symbol from ident (type is set to null).
   * @param ident the identifier of the symbol
   ***************************************************************************/
  public FormulaSymbol(FormulaDeclIdentifier ident)
  {
    super(ident);
  }
  
  /****************************************************************************
   * Return identifier of symbol.
   * @return the symbol identifier
   ***************************************************************************/
  public FormulaDeclIdentifier getFormulaDeclIdentifier()
  {
    return (FormulaDeclIdentifier)getIdentifier();
  }
  
  /****************************************************************************
   * Return formula of symbol.
   * @return the symbol formula
   ***************************************************************************/
  public Expression getFormula()
  {
    return formula;
  }
  
  /****************************************************************************
   * Set formula of symbol.
   * @param formula the symbol formula
   ***************************************************************************/
  public void setFormula(Expression formula)
  {
    this.formula = formula;
  }
  
  /****************************************************************************
   * Return environment of symbol (up to the point where the symbol was decld).
   * @return the symbol environment
   ***************************************************************************/
  public Environment getEnvironment()
  {
    return env;
  }
  
  /****************************************************************************
   * Set environment of symbol (up to the point where the symbol was decld).
   * @param env the symbol environment
   ***************************************************************************/
  public void setEnvironment(Environment env)
  {
    this.env = env;
  }
  
  /****************************************************************************
   * Return proof of symbol.
   * @return the symbol proof
   ***************************************************************************/
  public Proof getProof()
  {
    return proof;
  }
  
  /****************************************************************************
   * Set proof of symbol.
   * @param proof the symbol proof
   ***************************************************************************/
  public void setProof(Proof proof)
  {
    this.proof = proof;
  }
  
  /****************************************************************************
   * Return axiom status of formula.
   * @return true iff formula is axiom.
   ***************************************************************************/
  public boolean isAxiom()
  {
    return axiom;
  }
  
  /****************************************************************************
   * Set axiom status of formula to true.
   ***************************************************************************/
  public void setAxiom()
  {
    this.axiom = true;
  }
}
