// ----------------------------------------------------------------------------
// SymbolTable.java
// Base class of symbol tables.
// $Id: SymbolTable.java,v 1.8 2005/10/24 19:15:04 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.Semantics;
import fmrisc.Syntax.*;

import java.util.*;

/**
 * 
 * Base class of symbol tables.
 * 
 */
public abstract class SymbolTable
{
  // our symbol collection
  private HashMap table = new HashMap();
  
  /****************************************************************************
   * makes s a clone of the symbol table, the clone is a shallow copy
   * (the symbols in the table are not cloned)
   * @param s the symbol table which becomes a clone of this table
   ***************************************************************************/
  public SymbolTable cloneTable(SymbolTable s)
  {
    s.table = (HashMap)(table.clone());
    return s;
  }
  
  /****************************************************************************
   * puts <key,value> into table
   * @param key the lookup key
   * @param value the associated value
   ***************************************************************************/
  protected void put(Identifier key, Symbol value)
  {
    table.put(key.getName(), value);
  }
  
  /****************************************************************************
   * returns value associated to key
   * @param key the lookup key
   * @returns the associated value
   ***************************************************************************/
  protected Symbol get(Identifier key)
  {
    return (Symbol)table.get(key.getName());
  }
  
  /***************************************************************************
   * get all symbols in table
   * @return collection of all symbols
   **************************************************************************/
  protected Collection getAll()
  {
    return table.values();
  }
  
  /***************************************************************************
   * is symbol table empty?
   * @return true iff table is empty
   **************************************************************************/
  protected boolean isEmpty()
  {
    return table.isEmpty();
  }
  
  /***************************************************************************
   * Get all symbols.
   * @return collection of all symbols stored in this table.
   **************************************************************************/
  public Collection getSymbols()
  {
    return table.values();
  }
}
