// ----------------------------------------------------------------------------
// ExistsFormula.java
// Handling of existentially quantified formulas.
// $Id: ExistsFormula.java,v 1.11 2006/02/23 19:51:07 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.Syntax;

import java.io.*;

/**
 * Handling of universally quantified formulas.
 */
public final class ExistsFormula extends QuantifiedExpression
{
  /****************************************************************************
   * construct exists formula of variables and base formula
   * @param variables the quantified variables
   * @param base the base formula
   ***************************************************************************/
  public ExistsFormula(TypedIdentifier[] variables, Expression base)
  {
    super("EXISTS", variables, base);
  }
  
  /***************************************************************************
   * Construct quantified expression.
   * @param variables typed variables.
   * @param base an expression.
   * @return a quantified expression of the same kind as this expression
   *         with the denoted variables and base expression.
   **************************************************************************/
  public QuantifiedExpression construct(
    TypedIdentifier[] variables, Expression base)
  {
    return Construct.existsFormula(variables, base);
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * @param out the stream on which the text is written
   **************************************************************************/
  public void printCore(PrintWriter out)
  {
    int ov = ASTUtil.getVarNumber(); 
    Expression constraint = printHead(out);
    Expression exp = getBase();
    if (constraint != null) exp = Construct.andFormula(constraint, exp); 
    exp.printPriority(getPriority(), out);
    ASTUtil.setVarNumber(ov);
  }
}
