// ----------------------------------------------------------------------------
// SelectorIndex.java
// General index expression as selector.
// $Id: SelectorIndex.java,v 1.9 2006/02/23 19:51:06 schreine Exp $
//
// Author: Wolfgang Schreiner <Wolfgang.Schreiner@risc.uni-linz.ac.at>
// Copyright (C) 2005, Research Institute for Symbolic Computation (RISC)
// Johannes Kepler University, Linz, Austria, http://www.risc.uni-linz.ac.at
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
// ----------------------------------------------------------------------------
package fmrisc.Syntax;

import java.io.*;

/**
 * General index expression as selector.
 */
public final class SelectorIndex extends SelectorBase
{
  private Expression base; // the base index
  
  /****************************************************************************
   * make selector from general index expression
   * @param base the selector base
   ***************************************************************************/
  public SelectorIndex(Expression base)
  {
    this.base = base;
  }
  
  /***************************************************************************
   * get index expression
   * @return the index expression
   **************************************************************************/
  public Expression getIndex()
  {
    return base;
  }
  
  /***************************************************************************
   * return copy of AST with value references instantiated by the substitutions
   * set in the corresponding declaration identifiers
   * @return the instantiated copy
   **************************************************************************/
  public Selector instantiate()
  {
    return Construct.selectorIndex(getIndex().instantiate());
  }
  
  /***************************************************************************
   * Prints text representation on out (without new line termination).
   * @param out the stream on which the text is written
   **************************************************************************/
  public void printCore(PrintWriter out)
  {
    out.print('[');
    base.printCore(out);
    out.print(']');
  }
  
  /***************************************************************************
   * Accept visitor for a visit.
   * @param visitor the visitor who is accepted by this node.
   * @return the result of the visit (may be null)
   **************************************************************************/
  public AST accept(ASTVisitor visitor) 
  { 
    AST result = visitor.visit(this);
    if (result != null) return result;
    AST base0 = base.accept(visitor);
    if (!visitor.isCloned()) return null;
    return Construct.selectorIndex((Expression)base0);
  }
}
